@@ -240,7 +240,7 @@ dev.off()
 }
 if (plotype==2){
 {
-jpeg(file=fileName)
+jpeg(filename=fileName)
 internalGLord()
 }
 dev.off()
