@@ -18,7 +18,7 @@ for (item in 1:ncol(data)) {
         data2 <- data[, anchor]
         if (sum(anchor == item) == 0) 
             data2 <- cbind(data2, data[, item])
-        score <- rowSums(data2)
+        score <- rowSums(data2,na.rm=TRUE)
         Scores <- sort(unique(score))
         SCORES <- rep(Scores, nGroup + 1)
         GE <- sort(unique(member))
